@@ -13,7 +13,7 @@
  * You should have received a copy of the GNU General Public License
  * along with the hkl library.  If not, see <http://www.gnu.org/licenses/>.
  *
- * Copyright (C) 2003-2018 Synchrotron SOLEIL
+ * Copyright (C) 2003-2019 Synchrotron SOLEIL
  *                         L'Orme des Merisiers Saint-Aubin
  *                         BP 48 91192 GIF-sur-YVETTE CEDEX
  *
@@ -27,21 +27,10 @@
 G_BEGIN_DECLS
 
 /* HklGui3D */
+#define HKL_GUI_TYPE_3D (hkl_gui_3d_get_type ())
+G_DECLARE_FINAL_TYPE (HklGui3D, hkl_gui_3d, HKL_GUI, 3D, GObject)
 
-#define HKL_GUI_TYPE_3D            (hkl_gui_3d_get_type ())
-#define HKL_GUI_3D(obj)            (G_TYPE_CHECK_INSTANCE_CAST ((obj), HKL_GUI_TYPE_3D, HklGui3D))
-#define HKL_GUI_3D_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST ((klass), HKL_GUI_TYPE_3D, HklGui3DClass))
-#define HKL_GUI_IS_3D(obj)         (G_TYPE_CHECK_INSTANCE_TYPE ((obj), HKL_GUI_TYPE_3D))
-#define HKL_GUI_IS_3D_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), HKL_GUI_TYPE_3D))
-#define HKL_GUI_3D_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS ((obj), HKL_GUI_TYPE_3D, HklGuiEngineClass))
-
-typedef struct _HklGui3D HklGui3D;
-typedef struct _HklGui3DClass HklGui3DClass;
-typedef struct _HklGui3DPrivate HklGui3DPrivate;
-
-GType hkl_gui_3d_get_type (void) G_GNUC_CONST;
-
-HklGui3D *hkl_gui_3d_new (const char *filename, HklGeometry *geometry);
+	HklGui3D *hkl_gui_3d_new (const char *filename, HklGeometry *geometry);
 
 void hkl_gui_3d_is_colliding(HklGui3D *self);
 
