@@ -26,6 +26,12 @@
 
 #include "hkl-axis-private.h" /* temporary */
 
+#define GET_AXIS(_geometries, _name) hkl_parameter_value_get(		\
+		hkl_geometry_axis_get(					\
+			hkl_geometry_list_item_geometry_get(		\
+				hkl_geometry_list_items_first_get((geometries))), \
+			#_name, NULL), HKL_UNIT_USER)
+
 #define GET_GAMMA(geometries) hkl_parameter_value_get(			\
 		hkl_geometry_axis_get(					\
 			hkl_geometry_list_item_geometry_get(		\
@@ -152,12 +158,81 @@ static void med_2_3(void)
 	hkl_geometry_free(geometry);
 }
 
+static void med_2_3_v2(void)
+{
+	int res = TRUE;
+	HklEngineList *engines;
+	HklEngine *hkl;
+	HklGeometry *geometry;
+	HklGeometryList *geometries;
+	HklDetector *detector;
+	HklSample *sample;
+	static double hkl_p[] = {1.95, 2, 6};
+	static double values[] = {1};
+
+	static struct Sample gaas = {
+		.name = "GaAs",
+		.lattice = Hexagonal(4.759, 12.992),
+		.ux = -90.59 * HKL_DEGTORAD,
+		.uy = -9.97 * HKL_DEGTORAD,
+		.uz = 176.35 * HKL_DEGTORAD,
+	};
+
+	static struct Geometry gconfig = SoleilSixsMed2_3_v2(1.54980,
+							     1, -14.27, 99.62, 60.98, 10);
+
+	/* Wavelength 1.54980 */
+	/* Mode       mu_fixed */
+	/* Ux -90.59 Uy -9.97 Uz 176.35  */
+	/* A 4.759 B 4.759 C 12.992  */
+	/* Alpha 90 Beta 90 Gamma 120  */
+
+	geometry = newGeometry(gconfig);
+	engines = newEngines(gconfig);
+	sample = newSample(gaas);
+	detector = hkl_detector_factory_new(HKL_DETECTOR_TYPE_0D);
+
+	hkl_engine_list_init(engines, geometry, detector, sample);
+
+	hkl = hkl_engine_list_engine_get_by_name(engines, "hkl", NULL);
+
+	/* hkl 1.95, 2, 6 (should not fail) */
+	geometries = hkl_engine_pseudo_axis_values_set(hkl,
+						       hkl_p, ARRAY_SIZE(hkl_p),
+						       HKL_UNIT_DEFAULT, NULL);
+	res &= DIAG((geometries != NULL));
+
+	/* check that eta_a did not moved */
+	is_double(10.0, GET_AXIS(geometries, eta_a), HKL_EPSILON * 10, __func__);
+	hkl_geometry_list_free(geometries);
+
+
+	/* now make it move */
+	res &= DIAG(hkl_engine_list_parameters_values_set(engines,
+							  values, ARRAY_SIZE(values),
+							  HKL_UNIT_USER, NULL));
+	geometries = hkl_engine_pseudo_axis_values_set(hkl,
+						       hkl_p, ARRAY_SIZE(hkl_p),
+						       HKL_UNIT_DEFAULT, NULL);
+	is_double(-80.079231, GET_AXIS(geometries, eta_a), HKL_EPSILON * 10, __func__);
+	hkl_geometry_list_free(geometries);
+
+	ok(res == TRUE, __func__);
+
+	hkl_engine_list_free(engines);
+	hkl_detector_free(detector);
+	hkl_sample_free(sample);
+	hkl_geometry_free(geometry);
+}
+
+
 int main(void)
 {
-	plan(4);
+	plan(7);
 
 	qper_qpar();
 	med_2_3();
+	med_2_3_v2();
 
 	return 0;
 }
